#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COMBS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COMBS_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/scalar/combs.hpp>

#endif
